==> apo-ws-client-6.00.50.3-sources.jar: fr/univlorraine/apowsclient/creationSE/VdiFractionnerVetDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VdiFractionnerVetDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="VdiFractionnerVetDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codDip"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="7"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int"/&gt;
 *         &lt;element name="codEtp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionEtp" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int"/&gt;
 *         &lt;element name="anMinEtpDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="anMaxEtpDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="debutRecrutement" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="finRecrutement" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="debutValidation" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="finValidation" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VdiFractionnerVetDTO", namespace = "VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codDip",
    "codVersionDip",
    "codEtp",
    "codVersionEtp",
    "anMinEtpDip",
    "anMaxEtpDip",
    "debutRecrutement",
    "finRecrutement",
    "debutValidation",
    "finValidation"
})
public class VdiFractionnerVetDTO {

    @XmlElement(required = true, nillable = true)
    protected String codDip;
    @XmlElement(required = true, nillable = true)
    protected String codVersionDip;
    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String codVersionEtp;
    @XmlElement(required = true, nillable = true)
    protected String anMinEtpDip;
    @XmlElement(required = true, nillable = true)
    protected String anMaxEtpDip;
    @XmlElement(nillable = true)
    protected String debutRecrutement;
    @XmlElement(nillable = true)
    protected String finRecrutement;
    @XmlElement(nillable = true)
    protected String debutValidation;
    @XmlElement(nillable = true)
    protected String finValidation;

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionDip() {
        return codVersionDip;
    }

    /**
     * Définit la valeur de la propriété codVersionDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionDip(String value) {
        this.codVersionDip = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété anMinEtpDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAnMinEtpDip() {
        return anMinEtpDip;
    }

    /**
     * Définit la valeur de la propriété anMinEtpDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAnMinEtpDip(String value) {
        this.anMinEtpDip = value;
    }

    /**
     * Obtient la valeur de la propriété anMaxEtpDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAnMaxEtpDip() {
        return anMaxEtpDip;
    }

    /**
     * Définit la valeur de la propriété anMaxEtpDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAnMaxEtpDip(String value) {
        this.anMaxEtpDip = value;
    }

    /**
     * Obtient la valeur de la propriété debutRecrutement.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDebutRecrutement() {
        return debutRecrutement;
    }

    /**
     * Définit la valeur de la propriété debutRecrutement.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDebutRecrutement(String value) {
        this.debutRecrutement = value;
    }

    /**
     * Obtient la valeur de la propriété finRecrutement.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFinRecrutement() {
        return finRecrutement;
    }

    /**
     * Définit la valeur de la propriété finRecrutement.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFinRecrutement(String value) {
        this.finRecrutement = value;
    }

    /**
     * Obtient la valeur de la propriété debutValidation.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDebutValidation() {
        return debutValidation;
    }

    /**
     * Définit la valeur de la propriété debutValidation.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDebutValidation(String value) {
        this.debutValidation = value;
    }

    /**
     * Obtient la valeur de la propriété finValidation.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFinValidation() {
        return finValidation;
    }

    /**
     * Définit la valeur de la propriété finValidation.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFinValidation(String value) {
        this.finValidation = value;
    }

}

==> apo-ws-client-6.00.50.4-sources.jar: fr/univlorraine/apowsclient/creationSE/VdiFractionnerVetDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour VdiFractionnerVetDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="VdiFractionnerVetDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codDip"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="7"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int"/&gt;
 *         &lt;element name="codEtp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionEtp" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int"/&gt;
 *         &lt;element name="anMinEtpDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="anMaxEtpDip" type="{VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt"/&gt;
 *         &lt;element name="debutRecrutement" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="finRecrutement" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="debutValidation" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="finValidation" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VdiFractionnerVetDTO", namespace = "VdiFractionnerVetDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codDip",
    "codVersionDip",
    "codEtp",
    "codVersionEtp",
    "anMinEtpDip",
    "anMaxEtpDip",
    "debutRecrutement",
    "finRecrutement",
    "debutValidation",
    "finValidation"
})
public class VdiFractionnerVetDTO {

    @XmlElement(required = true, nillable = true)
    protected String codDip;
    @XmlElement(required = true, nillable = true)
    protected String codVersionDip;
    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String codVersionEtp;
    @XmlElement(required = true, nillable = true)
    protected String anMinEtpDip;
    @XmlElement(required = true, nillable = true)
    protected String anMaxEtpDip;
    @XmlElementRef(name = "debutRecrutement", type = JAXBElement.class, required = false)
    protected JAXBElement<String> debutRecrutement;
    @XmlElementRef(name = "finRecrutement", type = JAXBElement.class, required = false)
    protected JAXBElement<String> finRecrutement;
    @XmlElementRef(name = "debutValidation", type = JAXBElement.class, required = false)
    protected JAXBElement<String> debutValidation;
    @XmlElementRef(name = "finValidation", type = JAXBElement.class, required = false)
    protected JAXBElement<String> finValidation;

    /**
     * Obtient la valeur de la propriété codDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodDip() {
        return codDip;
    }

    /**
     * Définit la valeur de la propriété codDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodDip(String value) {
        this.codDip = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionDip() {
        return codVersionDip;
    }

    /**
     * Définit la valeur de la propriété codVersionDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionDip(String value) {
        this.codVersionDip = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété anMinEtpDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAnMinEtpDip() {
        return anMinEtpDip;
    }

    /**
     * Définit la valeur de la propriété anMinEtpDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAnMinEtpDip(String value) {
        this.anMinEtpDip = value;
    }

    /**
     * Obtient la valeur de la propriété anMaxEtpDip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAnMaxEtpDip() {
        return anMaxEtpDip;
    }

    /**
     * Définit la valeur de la propriété anMaxEtpDip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAnMaxEtpDip(String value) {
        this.anMaxEtpDip = value;
    }

    /**
     * Obtient la valeur de la propriété debutRecrutement.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getDebutRecrutement() {
        return debutRecrutement;
    }

    /**
     * Définit la valeur de la propriété debutRecrutement.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setDebutRecrutement(JAXBElement<String> value) {
        this.debutRecrutement = value;
    }

    /**
     * Obtient la valeur de la propriété finRecrutement.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getFinRecrutement() {
        return finRecrutement;
    }

    /**
     * Définit la valeur de la propriété finRecrutement.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setFinRecrutement(JAXBElement<String> value) {
        this.finRecrutement = value;
    }

    /**
     * Obtient la valeur de la propriété debutValidation.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getDebutValidation() {
        return debutValidation;
    }

    /**
     * Définit la valeur de la propriété debutValidation.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setDebutValidation(JAXBElement<String> value) {
        this.debutValidation = value;
    }

    /**
     * Obtient la valeur de la propriété finValidation.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getFinValidation() {
        return finValidation;
    }

    /**
     * Définit la valeur de la propriété finValidation.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setFinValidation(JAXBElement<String> value) {
        this.finValidation = value;
    }

}
